import csv

class Contact:
    def __init__(self, name, phone):
        self.name = name
        self.phone = phone

    def __str__(self):
        return f"姓名: {self.name}, 电话: {self.phone}"

class AddressBook:
    def __init__(self, filename):
        self.filename = filename
        self.contacts = self.load_contacts()

    def load_contacts(self):
        try:
            with open(self.filename, 'r', newline='', encoding='utf-8') as file:
                reader = csv.reader(file)
                contacts = [Contact(row[0], row[1]) for row in reader]
            return contacts
        except FileNotFoundError:
            return []

    def save_contacts(self):
        with open(self.filename, 'w', newline='', encoding='utf-8') as file:
            writer = csv.writer(file)
            for contact in self.contacts:
                writer.writerow([contact.name, contact.phone])

    def add_contact(self, name, phone):
        self.contacts.append(Contact(name, phone))
        self.save_contacts()

    def find_contact(self, name):
        for contact in self.contacts:
            if contact.name == name:
                return contact
        return None

    def update_contact(self, name, new_name=None, new_phone=None):
        contact = self.find_contact(name)
        if contact:
            if new_name:
                contact.name = new_name
            if new_phone:
                contact.phone = new_phone
            self.save_contacts()
            return True
        return False

    def list_contacts(self):
        for contact in self.contacts:
            print(contact)

def main():
    filename = 'contacts.csv'
    ab = AddressBook(filename)

    while True:
        print("===================================欢迎使用通讯录功能===================================")
        print("添加联系人 【输入1】")
        print("查询联系人 【输入2】")
        print("修改联系人 【输入3】")
        print("查看所有联系人 【输入4】")
        print("退出 【输入5】")
        print("===================================")

        choice = input("请输入您的选择: ")

        if choice == '1':
            name = input("请输入要添加的联系人姓名: ")
            phone = input("请输入要添加的联系人电话号码: ")
            ab.add_contact(name, phone)
            print(f"新的联系人信息已经添加，联系人姓名: {name}, 电话号码: {phone}")

        elif choice == '2':
            name = input("请输入要查询的联系人姓名: ")
            contact = ab.find_contact(name)
            if contact:
                print(contact)
            else:
                print("未找到该联系人")

        elif choice == '3':
            name = input("请输入要修改的联系人姓名: ")
            new_name = input("请输入新的联系人姓名（留空则不修改）: ")
            new_phone = input("请输入新的联系人电话号码（留空则不修改）: ")
            if ab.update_contact(name, new_name if new_name else None, new_phone if new_phone else None):
                print("联系人信息已更新")
            else:
                print("未找到该联系人")

        elif choice == '4':
            ab.list_contacts()

        elif choice == '5':
            print("退出程序")
            break

        else:
            print("无效的选择，请重新输入")

if __name__ == "__main__":
    main()